List
----
A list manipulation module.

**Functions**:

- ensure
- setDiff
- unique
- getSlot
- assocKeys

.. dropdown:: List.ils sourcecode

    .. literalinclude:: ../../_static/src/List.ils
       :language: scheme
       :linenos:
